@@ -338,3 +338,16 @@ class VariableClBuilderX11Composite(GrubOptionVariable,
                                     X11.VariableOsInstallX11Composite):
     def get(self):
         return self.Get('os_x11_composite')
+
+
+class VariableClBuilderDocacheSet(GrubOptionVariable, Variable):
+    """
+    Добавлить параметр docache в загрузку образа
+    """
+    type = "bool"
+    opt = ["--docache"]
+    value = "off"
+
+    def init(self):
+        self.label = _("Boot an image to RAM")
+        self.help = _("boot an image to RAM")
